@@ -4,15 +4,11 @@
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 
-#include "IPC.hpp"
-
-
-class cProcess: public Cipc
+class cProcess
 {
 
     private:
 
-	PROCESS_INFORMATION		procinfo;
 	HANDLE				ph;
 	HANDLE				th;
 		
@@ -23,6 +19,7 @@ class cProcess: public Cipc
 		  DWORD CreateFlags, char* szCurrDir)
 	    {
 		STARTUPINFO st;
+		PROCESS_INFORMATION		procinfo;
 
 		st.lpReserved=NULL;
 		st.cb = sizeof( STARTUPINFO );
@@ -31,6 +28,8 @@ class cProcess: public Cipc
 		st.dwFlags = 0;
 		st.cbReserved2 = 0;
 		st.lpReserved2 = NULL;
+		ph = NULL;
+		th = NULL;
 
 		bRetVal = CreateProcess( szAppName,szCommLine,NULL,NULL,
 					 Inherit,CreateFlags,NULL,szCurrDir,
@@ -39,13 +38,13 @@ class cProcess: public Cipc
 		if (bRetVal) {
 		    ph = procinfo.hProcess;
 		    th = procinfo.hThread;
-		    SetHandle(ph);
 		}
-		else
-		    SetHandle(NULL);
 	    }
 	~cProcess()
-	    { CloseHandle( MyHandle() ); }
+	    {
+		CloseHandle( th );
+		CloseHandle( ph );
+	    }
 	BOOL Kill(UINT uExitCode)
 	    { return TerminateProcess( ph, uExitCode ); }
 	BOOL Suspend()
@@ -59,6 +58,12 @@ class cProcess: public Cipc
 	    }
 	BOOL SetPriorityClass( DWORD dwPriorityClass )
 	    { return ::SetPriorityClass( ph, dwPriorityClass ); }
+	BOOL GetProcessAffinityMask( DWORD* pdwProcessAffinityMask, DWORD* pdwSystemAffinityMask )
+	    { return ::GetProcessAffinityMask( ph, pdwProcessAffinityMask, pdwSystemAffinityMask ); }
+	BOOL SetProcessAffinityMask( DWORD dwProcessAffinityMask )
+	    { return ::SetProcessAffinityMask( ph, dwProcessAffinityMask ); }
 	BOOL GetExitCode( DWORD* pdwExitCode )
 	    { return GetExitCodeProcess( ph, pdwExitCode ); }
+	DWORD Wait( DWORD TimeOut )
+	    { return WaitForSingleObject( ph, TimeOut ); }
 };
